@@ -8,13 +8,14 @@ matr_cor <- matrix(seq(1,10,1), 10,10)
 NMRData_plot <- matrix(seq(1,10,1), 10,10)
 p_value <<- 0.05
 choose_norm <<- 1
+stop_menssager <<- 0
 
 # não esquecer de voltar matr_cor
 onStop(function() {
 
   message("Stopping iSTATS ...\n")
 
-  clear_list <- c("rr_nn","norm_var","col_sel_norm2","yinf","NMRData_plot","peran","rows_temp","p_value","choose_norm","testy_norm","NMR_sqr",
+  clear_list <- c("stop_menssager","n_dpi","rr_nn","norm_var","col_sel_norm2","yinf","NMRData_plot","peran","rows_temp","p_value","choose_norm","testy_norm","NMR_sqr",
                   "NMR_Pareto","NMR_MC","NMR_log","NMR_i_sqr","NMR_ASC","matr_cor","s_stoc","rr2",
                   "rowns_temp","dif","cor_cutoff_value_p","cor_cutoff_value_n","col_sel_norm",
                   "test_norm","R_CRITICAL","rr_n","CS_norm","CS_selection","gg","gr","buma","CS_values_real",
